@@ -1,4 +1,4 @@
-#ifndef USE_BOOST_129
+#ifdef USE_BOOST_128
 //  (C) Copyright David Abrahams 2000. Permission to copy, use, modify, sell and
 //  distribute this software is granted provided this copyright notice appears
 //  in all copies. This software is provided "as is" without express or implied
