@@ -309,6 +309,8 @@ namespace boost {
   template <typename VertexListGraph, typename MutableGraph>
   void copy_graph(const VertexListGraph& g_in, MutableGraph& g_out)
   {
+    if (num_vertices(g_in) == 0)
+      return;
     typedef typename graph_traits<MutableGraph>::vertex_descriptor vertex_t;
     std::vector<vertex_t> orig2copy(num_vertices(g_in));
     typedef typename detail::choose_graph_copy<VertexListGraph>::type 
@@ -331,7 +333,9 @@ namespace boost {
     typename std::vector<T>::size_type n;
       n = is_default_param(get_param(params, orig_to_copy_t()))
         ? num_vertices(g_in) : 1;
-    std::vector<typename graph_traits<VertexListGraph>::vertex_descriptor> 
+    if (n == 0)
+      return;
+    std::vector<BOOST_DEDUCED_TYPENAME graph_traits<MutableGraph>::vertex_descriptor> 
       orig2copy(n);
 
     typedef typename detail::choose_graph_copy<VertexListGraph>::type 
@@ -345,9 +349,9 @@ namespace boost {
        choose_param(get_param(params, orig_to_copy_t()),
                     make_iterator_property_map
                     (orig2copy.begin(), 
-                     choose_pmap(get_param(params, vertex_index), 
+                     choose_const_pmap(get_param(params, vertex_index), 
                                  g_in, vertex_index), orig2copy[0])),
-       choose_pmap(get_param(params, vertex_index), g_in, vertex_index)
+       choose_const_pmap(get_param(params, vertex_index), g_in, vertex_index)
        );
   }
 
@@ -433,7 +437,7 @@ namespace boost {
                     make_iterator_property_map
                     (orig2copy.begin(), 
                      choose_pmap(get_param(params, vertex_index), 
-                                 g, vertex_index), orig2copy[0])),
+                                 g_in, vertex_index), orig2copy[0])),
        params
        );
   }
