@@ -128,7 +128,7 @@ template<>
 struct empty_traits< aux::vector_tag< 21> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -137,7 +137,7 @@ template<>
 struct size_traits< aux::vector_tag< 21> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,21 >
+        : integral_c< long,21 >
     {
     };
 };
@@ -284,7 +284,7 @@ template<>
 struct empty_traits< aux::vector_tag< 22> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -293,7 +293,7 @@ template<>
 struct size_traits< aux::vector_tag< 22> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,22 >
+        : integral_c< long,22 >
     {
     };
 };
@@ -441,7 +441,7 @@ template<>
 struct empty_traits< aux::vector_tag< 23> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -450,7 +450,7 @@ template<>
 struct size_traits< aux::vector_tag< 23> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,23 >
+        : integral_c< long,23 >
     {
     };
 };
@@ -601,7 +601,7 @@ template<>
 struct empty_traits< aux::vector_tag< 24> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -610,7 +610,7 @@ template<>
 struct size_traits< aux::vector_tag< 24> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,24 >
+        : integral_c< long,24 >
     {
     };
 };
@@ -762,7 +762,7 @@ template<>
 struct empty_traits< aux::vector_tag< 25> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -771,7 +771,7 @@ template<>
 struct size_traits< aux::vector_tag< 25> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,25 >
+        : integral_c< long,25 >
     {
     };
 };
@@ -927,7 +927,7 @@ template<>
 struct empty_traits< aux::vector_tag< 26> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -936,7 +936,7 @@ template<>
 struct size_traits< aux::vector_tag< 26> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,26 >
+        : integral_c< long,26 >
     {
     };
 };
@@ -1093,7 +1093,7 @@ template<>
 struct empty_traits< aux::vector_tag< 27> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -1102,7 +1102,7 @@ template<>
 struct size_traits< aux::vector_tag< 27> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,27 >
+        : integral_c< long,27 >
     {
     };
 };
@@ -1262,7 +1262,7 @@ template<>
 struct empty_traits< aux::vector_tag< 28> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -1271,7 +1271,7 @@ template<>
 struct size_traits< aux::vector_tag< 28> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,28 >
+        : integral_c< long,28 >
     {
     };
 };
@@ -1432,7 +1432,7 @@ template<>
 struct empty_traits< aux::vector_tag< 29> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -1441,7 +1441,7 @@ template<>
 struct size_traits< aux::vector_tag< 29> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,29 >
+        : integral_c< long,29 >
     {
     };
 };
@@ -1605,7 +1605,7 @@ template<>
 struct empty_traits< aux::vector_tag< 30> >
 {
     template< typename Vector > struct algorithm
-        : false_c
+        : false_
     {
     };
 };
@@ -1614,7 +1614,7 @@ template<>
 struct size_traits< aux::vector_tag< 30> >
 {
     template< typename Vector > struct algorithm
-        : integral_c< int,30 >
+        : integral_c< long,30 >
     {
     };
 };
