@@ -10,6 +10,7 @@
 # include <boost/python/converter/registrations.hpp>
 # include <boost/type_traits/transform_traits.hpp>
 # include <boost/type_traits/cv_traits.hpp>
+# include <boost/detail/workaround.hpp>
 
 namespace boost { namespace python { namespace converter { 
 
@@ -34,10 +35,15 @@ struct registered
 {
 };
 
-# ifndef BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION
-// collapses a few more types to the same static instance
+# if !defined(BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) \
+    && !BOOST_WORKAROUND(BOOST_MSVC, BOOST_TESTED_AT(1310))
+// collapses a few more types to the same static instance.  MSVC7.1
+// fails to strip cv-qualification from array types in typeid.  For
+// some reason we can't use this collapse there or array converters
+// will not be found.
 template <class T>
-struct registered<T&> : registered<T> {};
+struct registered<T&>
+  : registered<T> {};
 # endif
 
 //
