@@ -6,14 +6,17 @@
 #ifndef HAS_BACK_REFERENCE_DWA2002323_HPP
 # define HAS_BACK_REFERENCE_DWA2002323_HPP
 
+# include <boost/python/detail/prefix.hpp>
+# include <boost/mpl/bool.hpp>
+
 namespace boost { namespace python { 
 
 // traits class which users can specialize to indicate that a class
 // contains a back-reference to its owning PyObject*
 template <class T>
 struct has_back_reference
+  : mpl::false_
 {
-    BOOST_STATIC_CONSTANT(bool, value = false);
 };
 
 
