@@ -1,4 +1,7 @@
-#ifdef USE_BOOST_129
+#ifdef USE_BOOST_131
+#if defined (_MSC_VER) && _MSC_VER<=1200
+#define Vector Vactor
+#endif
 // Copyright David Abrahams 2002. Permission to copy, use,
 // modify, sell and distribute this software is granted provided this
 // copyright notice appears in all copies. This software is provided
@@ -39,4 +42,7 @@ long_base::long_base(object_cref arg, object_cref base)
 
 
 }}} // namespace boost::python
+#if defined (_MSC_VER) && _MSC_VER<=1200
+#undef Vector
 #endif
+#endif
\ No newline at end of file
