@@ -23,12 +23,20 @@
   c_alike scripting written by Alexander Rawass <alexannika@users.sourceforge.net>
 */
 
+#include "config.h"
 
 #include <stdio.h>
-#if defined(__APPLE__) || defined(MACOSX)
-    #include <sys/malloc.h>
+
+#if defined(HAVE_LINUX_SLAB_H)
+	#include <linux/slab.h>
+#elif defined(HAVE_LINUX_MALLOC_H)
+	#include <linux/malloc.h>
+#elif defined(__APPLE__) || defined(MACOSX)
+	#include <sys/malloc.h>
+#elif defined(HAVE_MALLOC_H)
+    	#include <malloc.h>
 #else
-    #include <malloc.h>
+	#include <stdlib.h>
 #endif
 #include <vector>
 #include <string>
@@ -41,6 +49,7 @@ using std::string;
 
 extern std::string parseCalike(char const *filename);
 extern int yyerror(char *);
+extern int yyparse();
 extern int yywrap();
 extern int yylex();
 
@@ -57,5 +66,11 @@ extern	int yylineno;
 extern char *yytext;
 extern FILE *yyin;
 
-#include "c_alike.tab.cpp.h"
 
+extern YYSTYPE yylval;
+
+#if defined(BISON)
+#include "c_alike.tab.hpp"
+#else
+#include "c_alike.tab.cpp.h"
+#endif
