@@ -299,9 +299,6 @@ void Mission::call_olist_toxml(missionNode *node,int mode,varInst *ovi){
 	  char buffer[200];
 	  sprintf(buffer,"<olist index=\"%d\"",i);
 	  debug(3,node,mode,buffer);
-	  var_out << buffer << " " ;
-	  saveVarInst(vi,var_out);
-	  var_out << "</olist>" << endl;
 	}
 
 }
