@@ -724,64 +724,7 @@ var_type Mission::vartypeFromString(string type){
 /* *********************************************************** */
 
 void Mission::saveVariables(const ostream& out){
-#if 0
-  //causes segfault..
-  var_out << "<!-- saved variables generated by Vegastrike -->" << endl << endl;
   
-  var_out << "<saved-variables>" << endl << endl;
-
-  var_out << "    <globals>" << endl;
-
-  map<string,missionNode *>::iterator iter;
-
-  for(iter=runtime.global_variables.begin();iter!=runtime.global_variables.end();iter++){
-    string name=(*iter).first;
-    missionNode *gnode=(*iter).second;
-
-    varInst *vi=gnode->script.varinst;
-
-    //    var_out << "      <defvar name=\"" << name << "\" type=\"" << typestr << "\" value=\"" << valuestr << "\" />" << endl;
-
-    var_out << "      <defvar name=\"" << name << "\" ";
-
-    saveVarInst(vi,var_out);
-
-    var_out << "</defvar> " << endl;
-  }
-
-  var_out << "    </globals>" << endl << endl;
-
-  {
-  // modules
-  map<string,missionNode *>::iterator iter;
-
-  for(iter=runtime.modules.begin();iter!=runtime.modules.end();iter++){
-    string mname=(*iter).first ;
-    missionNode *module_node=(*iter).second;
-
-    var_out << "    <module name=\"" << mname << "\" >" << endl;
-
-    // each module
-
-    vector<easyDomNode *>::const_iterator siter;
-  
-    for(siter= module_node->subnodes.begin() ; siter!=module_node->subnodes.end() ; siter++){
-
-    missionNode *varnode=(missionNode *)*siter;
-    if(varnode->tag==DTAG_DEFVAR){
-      // found a module var node
-      var_out << "      <defvar name=\"" << varnode->script.name << "\" ";
-      saveVarInst(varnode->script.varinst,var_out);
-      var_out << "</defvar> " << endl;
-    }
-  }
-
-    var_out << "    </module>" << endl << endl;
-  }
-  }
-
-  var_out << endl << "</saved-variables>" << endl;
-#endif
 }
 
 /* *********************************************************** */
@@ -789,34 +732,28 @@ void Mission::saveVariables(const ostream& out){
 void Mission::saveVarInst(varInst *vi,ostream& aa_out){
     char buffer[100];
     if(vi==NULL){
-      sprintf(buffer," NULL");
-      var_out  << buffer << endl;
+
     }
     else{
       if(vi->type==VAR_BOOL){
 	sprintf(buffer,"type=\"bool\" value=\"%d\" ",vi->bool_val);
-	var_out  << buffer << endl;
       }
       else if(vi->type==VAR_FLOAT){
 	sprintf(buffer,"type=\"float\"  value=\"%f\" ",vi->float_val);
-	var_out  << buffer << endl;
       }
       else if(vi->type==VAR_INT){
 	sprintf(buffer,"type=\"int\"  value=\"%d\" ",vi->int_val);
-	var_out  << buffer << endl;
       }
       else if(vi->type==VAR_OBJECT){
 	if(vi->objectname=="string"){
 	  string *sptr=(string *)vi->object;
 	  sprintf(buffer,"type=\"object\"  object=\"%s\" value=\"%s\" >\n ", vi->objectname.c_str(),sptr->c_str());
-	  var_out << buffer << endl;
 	}
 	else{
 	  sprintf(buffer,"type=\"object\"  object=\"%s\" value=\"0x%x\" >\n ", vi->objectname.c_str(),vi->object);
 	
 	  string modname="_"+vi->objectname;
 	
-	  var_out  << buffer << endl;
 
 	  doCall_toxml(modname,vi);
 	}
