@@ -204,8 +204,10 @@ bool Unit::InsideCollideTree (Unit * smaller, QVector & bigpos, Vector &bigNorma
       //printf ("um >1 for %s with %s\n",bigger->name.c_str(),smaller->name.c_str());
     }
 #endif
-    const csReversibleTransform bigtransform (/*WarpMatrixForCollisions(bigger)*/bigger->cumulative_transformation_matrix);
-	const csReversibleTransform smalltransform (/*WarpMatrixForCollisions(smaller)*/smaller->cumulative_transformation_matrix);
+    csReversibleTransform bigtransform (/*WarpMatrixForCollisions(bigger)*/bigger->cumulative_transformation_matrix);
+    csReversibleTransform smalltransform (/*WarpMatrixForCollisions(smaller)*/smaller->cumulative_transformation_matrix);
+    smalltransform.SetO2TTranslation(csVector3(smaller->cumulative_transformation_matrix.p-bigger->cumulative_transformation_matrix.p));
+      bigtransform.SetO2TTranslation(csVector3(0,0,0));
 #ifdef SUPERCOLLIDER
     for (int iter=1;iter<=/*um*/1;++iter) 
 #endif
@@ -395,9 +397,12 @@ Unit * Unit::BeamInsideCollideTree (const QVector & start,const QVector & end, Q
 
 
 bool Unit::Collide (Unit * target) {
-  if (target==this||((target->isUnit()!=NEBULAPTR&&isUnit()!=NEBULAPTR)&&(owner==target||target->owner==this||(owner!=NULL&&target->owner==owner))))
+  clsptr targetisUnit=target->isUnit();
+  clsptr thisisUnit=this->isUnit();
+  if (target==this||((targetisUnit!=NEBULAPTR&&thisisUnit!=NEBULAPTR)&&(owner==target||target->owner==this||(owner!=NULL&&target->owner==owner))))
+    return false;
+  if (targetisUnit==ASTEROIDPTR&&thisisUnit==ASTEROIDPTR)
     return false;
-
   //unit v unit? use point sampling?
   //now first make sure they're within bubbles of each other...
   if ((Position()-target->Position()).Magnitude()>radial_size+target->radial_size)
@@ -553,7 +558,7 @@ bool Unit::querySphere (const QVector &pnt, float err) const{
   
   Vector TargetPoint (tmpo->getP());
 #ifdef VARIABLE_LENGTH_PQR
-  float SizeScaleFactor = sqrtf(TargetPoint.Dot(TargetPoint));//adjust the ship radius by the scale of local coordinates
+  double SizeScaleFactor = sqrt(TargetPoint.Dot(TargetPoint));//adjust the ship radius by the scale of local coordinates
 #endif
   for (i=0;i<nummesh();i++) {
     TargetPoint = (Transform (*tmpo,meshdata[i]->Position()).Cast()-pnt).Cast();
@@ -602,7 +607,7 @@ float Unit::querySphere (const QVector &start, const QVector &end, float min_rad
 float Unit::querySphereNoRecurse (const QVector & start, const QVector & end, float min_radius) const {
 //	return querySphere(start,a(end-start).Magnitude());
   int i;
-  float tmp;
+  double tmp;
   QVector st,dir;
   //if( min_radius<0.00001)
   // min_radius = 0;
@@ -612,13 +617,13 @@ float Unit::querySphereNoRecurse (const QVector & start, const QVector & end, fl
 	}
 	if (isUnit()==PLANETPTR&&i>0)
 		break;
-    float a, b,c;
-    st = start - Transform (cumulative_transformation_matrix,meshdata[i]->Position()).Cast();	
+    double a, b,c;
+    st = start - Transform (cumulative_transformation_matrix,meshdata[i]->Position().Cast());	
     dir = end-start;//now start and end are based on mesh's position
     // v.Dot(v) = r*r; //equation for sphere
     // (x0 + (x1 - x0) *t) * (x0 + (x1 - x0) *t) = r*r
     c = st.Dot (st);
-	float temp1 = (min_radius+meshdata[i]->rSize());
+	double temp1 = (min_radius+meshdata[i]->rSize());
 	if( min_radius!=-FLT_MAX)
 		c = c - temp1*temp1;
 	else
@@ -637,8 +642,8 @@ float Unit::querySphereNoRecurse (const QVector & start, const QVector & end, fl
       continue;
     a *=2;
       
-    tmp = (-b + sqrtf (c))/a;
-    c = (-b - sqrtf (c))/a;
+    tmp = (-b + sqrt (c))/a;
+    c = (-b - sqrt (c))/a;
     if (tmp>0&&tmp<=1) {
       return (c>0&&c<tmp) ? c : tmp;
     } else if (c>0&&c<=1) {
