@@ -20,88 +20,33 @@
  */
 
 #include <stdio.h>
-#include "aux_texture.h"
 #include <assert.h>
 #include "gfxlib.h"
 #include <string>
 #include "endianness.h"
 #include "hashtable.h"
-#include "vs_path.h"
-#include "png_texture.h"
+#include "vsfilesystem.h"
+#include "vsimage.h"
 #include "vs_globals.h"
 #include "in_kb.h"
 #include "main_loop.h"
+#include "aux_texture.h"
 
 using std::string;
+using namespace VSFileSystem;
 
-
-#ifndef WIN32
-typedef unsigned int DWORD;
-typedef int  LONG;
-typedef unsigned short WORD;
-typedef unsigned char BYTE;
-/**
- * Windows Bitmap format.  Caution about mips systems which cannot handle
- * misaligned structs
- * Caution about big endian systems (use endianness.h to read in things)
- */
-typedef struct {
-        DWORD      biSize;
-        LONG       biWidth;
-        LONG       biHeight;
-        WORD       biPlanes;
-        WORD       biBitCount;
-        DWORD      biCompression;
-        DWORD      biSizeImage;
-        LONG       biXPelsPerMeter;
-        LONG       biYPelsPerMeter;
-        DWORD      biClrUsed;
-        DWORD      biClrImportant;
-} BITMAPINFOHEADER;
-/**
- * File header of a bitmap. Won't work on mips architecture with 
- * misaligned structs
- */
-typedef struct {
-        WORD    bfType;
-        DWORD   bfSize;
-        WORD    bfReserved1;
-        WORD    bfReserved2;
-        DWORD   bfOffBits;
-} BITMAPFILEHEADER;
-/**
- *  The color data of a bitmap
- */
-typedef struct {
-        BYTE    rgbBlue;
-        BYTE    rgbGreen;
-        BYTE    rgbRed;
-        BYTE    rgbReserved;
-} RGBQUAD;
-
-#else
-#include <windows.h>
-#include <wingdi.h>
-
-
-#endif
-///Defined for gcc which pads the size of structs
-const int SIZEOF_BITMAPFILEHEADER=sizeof(WORD)+sizeof(DWORD)+sizeof(WORD)+sizeof(WORD)+sizeof(DWORD);
-///Defined for gcc which pads the size of structs
-const int SIZEOF_BITMAPINFOHEADER= sizeof(DWORD)+sizeof(LONG)+sizeof(LONG)+2*sizeof(WORD)+2*sizeof(DWORD)+2*sizeof(LONG)+2*sizeof(DWORD);
-///defined for gcc which pads size of structs (not entirely necessary)
-const int SIZEOF_RGBQUAD=sizeof(BYTE)*4;
 ///holds all the textures in a huge hash table
-Hashtable<string, Texture,char [511]> texHashTable;
+Hashtable<string, Texture, 511> texHashTable;
+Hashtable<string, bool, 511> badtexHashTable;
 ///returns if a texture exists
 Texture * Texture::Exists (string s, string a) {
   return Texture::Exists (s+a);
 }
 Texture * Texture::Exists (string s) {
-  Texture * tmp = texHashTable.Get(GetHashName(s));
+  Texture * tmp = texHashTable.Get(VSFileSystem::GetHashName(s));
   if (tmp==NULL){
     string tmpo;
-    tmp = texHashTable.Get (GetSharedTextureHashName (s));
+    tmp = texHashTable.Get (VSFileSystem::GetSharedTextureHashName (s));
   }
   if (tmp)
     return tmp->Original();
@@ -118,20 +63,21 @@ bool Texture::operator == (Texture & b) {
 
 GFXBOOL Texture::checkold(string s, bool shared, string & hashname)
 {
-  hashname = shared?GetSharedTextureHashName(s):GetHashName(s);
+  hashname = shared?VSFileSystem::GetSharedTextureHashName(s):VSFileSystem::GetHashName(s);
   Texture *oldtex= texHashTable.Get (hashname);
   if(oldtex!=NULL) {
 	  //*this = *oldtex;//will be obsoleted--unpredictable results with string()
-    *this = *oldtex;
+	*this = *oldtex;
     original = oldtex;
     original->refcount++;
+	//cerr<<"Found cached texture : "<<s<<" with hashname="<<hashname<<endl;
     return GFXTRUE;
   } else {
     return GFXFALSE;
   }
 }
 void Texture::modold (string s, bool shared, string & hashname) {
-  hashname = shared?GetSharedTextureHashName(s):GetHashName(s);
+  hashname = shared?VSFileSystem::GetSharedTextureHashName(s):VSFileSystem::GetHashName(s);
   Texture * oldtex = new Texture;
   //  oldtex->InitTexture();new calls this
   oldtex->name=-1;
@@ -182,19 +128,49 @@ Texture *Texture::Clone () {
   
 }
 void Texture::FileNotFound(const string &texfilename) {
+	  // We may need to remove from texHashTable if we found the file but it is a bad one
 	  texHashTable.Delete (texfilename);
+
+	  setbad( texfilename);
 	  name=-1;
 	  data = NULL;
-	  original->name=-1;
-	  delete original;
-	  original=NULL;
+	  if( original != NULL)
+	  {
+	  	original->name=-1;
+	  	delete original;
+	  	original=NULL;
+	  }
 	  palette=NULL;
-	  
-	  return;
 
+	  return;
 }
-Texture::Texture (char * buffer, int length, int stage, enum FILTER  mipmap, enum TEXTURE_TARGET target, enum TEXTURE_IMAGE_TARGET imagetarget, float alpha, int zeroval, GFXBOOL force_load, int maxdimension, GFXBOOL detailtexture)
-//Texture::Texture(const char * buffer, int length, int stage, enum FILTER mipmap, enum TEXTURE_TARGET target, enum TEXTURE_IMAGE_TARGET imagetarget, GFXBOOL force_load, int maxdimension)
+
+bool Texture::checkbad( string & s)
+{
+  string hashname = VSFileSystem::GetSharedTextureHashName(s);
+  bool * found=NULL;
+  found = badtexHashTable.Get (hashname);
+  if(found!=NULL) {
+	return true;
+  }
+  hashname = VSFileSystem::GetHashName(s);
+  found= badtexHashTable.Get (hashname);
+  if(found!=NULL) {
+	return true;
+  }
+  return false;
+}
+
+void Texture::setbad( const string & s)
+{
+	// Put both current path+texfile and shared texfile since they both have been looked for
+	bool * b = new bool( true);
+	if( VSFileSystem::current_path.back()!="")
+		badtexHashTable.Put( VSFileSystem::GetHashName(s), b);
+	badtexHashTable.Put( VSFileSystem::GetSharedTextureHashName(s), b);
+}
+
+Texture::Texture(VSFile * f, int stage, enum FILTER mipmap, enum TEXTURE_TARGET target, enum TEXTURE_IMAGE_TARGET imagetarget, GFXBOOL force_load, int maxdimension,GFXBOOL detailtexture)
 {
 
   data = NULL;
@@ -203,128 +179,22 @@ Texture::Texture (char * buffer, int length, int stage, enum FILTER  mipmap, enu
   palette = NULL;
   texture_target =target;
   image_target=imagetarget;
-  int offset = 0;
   this->stage = stage;
-  //bootstrap_draw("Loading "+string(FileName));
+  data = this->ReadImage( f, NULL, true, NULL);
 
-	//	strcpy(filename, FileName);
-	int bpp;
-	int format;
-	data = readImage (buffer,length,bpp,format,sizeX,sizeY,palette,NULL/*texTransform*/,true);
-	if (data) {
-	  //FIXME deal with palettes and grayscale with alpha
-	  if (!(format&PNG_HAS_COLOR)||(format&PNG_HAS_PALETTE)) {
-	    mode=_8BIT;
-	    if (!(format&PNG_HAS_COLOR)){
-	      palette = (unsigned char *) malloc(sizeof(unsigned char)*(256*4+1));
-	      for (unsigned int i =0;i<256;i++) {
-		palette[i*4]=i;
-		palette[i*4+1]=i;
-		palette[i*4+2]=i;
-		palette[i*4+3]=255;
-	      }
-	    }
-	  } 
-	  if (format&PNG_HAS_COLOR) {
-	    if (format&PNG_HAS_ALPHA) {
-	      mode=_24BITRGBA;
-	    } else {
-	      mode=_24BIT;
-	    }
-	  }
-	}else {
-	  char head1;
-	  char head2;
-	  //fseek (fp,0,SEEK_SET);
-	  memcpy( &head1, buffer, 1);
-	  offset += 1;
-	  memcpy( &head2, buffer+offset, 1);
-	  //fread (&head1,1,1,fp);
-	  //fread (&head2,1,1,fp);
-	  if (toupper(head1)!='B'||toupper (head2)!='M') {
-		FileNotFound(texfilename);
-		return;
-	  }
-	  //seek back to beginning
-	  //fseek (fp,SIZEOF_BITMAPFILEHEADER,SEEK_SET);
-	  offset += SIZEOF_BITMAPFILEHEADER;
-	  //long temp;
-	  BITMAPINFOHEADER info;
-	  //fread(&info, SIZEOF_BITMAPINFOHEADER,1,fp);
-	  memcpy(&info, buffer+offset, SIZEOF_BITMAPINFOHEADER);
-	  offset += SIZEOF_BITMAPINFOHEADER;
-	  sizeX = le32_to_cpu(info.biWidth);	
-	  sizeY = le32_to_cpu(info.biHeight);
-	  
-	  
-	  //while(1);
-	  
-	  if(le16_to_cpu(info.biBitCount) == 24)
-	    {
-	      mode = _24BITRGBA;
-	      data = NULL;
-	      data= (unsigned char *)malloc (sizeof(unsigned char)*4*sizeY*sizeX); // all bitmap data needs to be 32 bits
-	      if (!data)
-		return;
-	      for (int i=sizeY-1; i>=0;i--)
-		{
-		  int itimes4width= 4*i*sizeX;//speed speed speed (well if I really wanted speed Pos'd have wrote this function)
-		  for (unsigned int j=0; j<sizeX;j++)
-		    {
-			*(data+3) = 0xff; // default alpha = 1
-		      for (int k=2; k>=0;k--)
-				{
-					//fread (data+k+4*j+itimes4width,sizeof (unsigned char),1,fp);
-					memcpy( data+k+4*j+itimes4width, buffer+offset, sizeof( unsigned char));
-					offset += sizeof( unsigned char);
-				}
-		    }
-		}
-	    }
-	  else if(le16_to_cpu(info.biBitCount) == 8)
-	    {
-	      mode = _8BIT;
-	      data = NULL;
-	      data= (unsigned char *)malloc(sizeof(unsigned char)*sizeY*sizeX);
-	      palette = (unsigned char *)malloc(sizeof(unsigned char)* (256*4+1));
-	      memset (palette,0,(256*4+1)*sizeof(unsigned char));
-	      unsigned char *paltemp = palette;
-	      unsigned char ctemp;
-		for(int palcount = 0; palcount < 256; palcount++)
-		  {
-		    //fread(paltemp, SIZEOF_RGBQUAD, 1, fp);
-			memcpy( paltemp, buffer+offset, SIZEOF_RGBQUAD);
-			offset+=SIZEOF_RGBQUAD;
-		    ctemp = paltemp[0];
-		    paltemp[0] = paltemp[2];
-		    paltemp[2] = ctemp;
-		    paltemp+=4; // pal size
-		  }
-		if (!data)
-		  return;
-		for (int i=sizeY-1; i>=0;i--)
-		  {
-		    for (unsigned int j=0; j<sizeX;j++)
-		      {
-				//fread (data+ j + i * sizeX,sizeof (unsigned char),1,fp);
-				memcpy( data+j+i*sizeX, buffer+offset, sizeof( unsigned char));
-				offset+= sizeof( unsigned char);
-		      }
-		  }
-	    }
-	}
-	fprintf (stderr,"Bind... ");
-	Bind(maxdimension,detailtexture);
 	if (data)
-	  free(data);
-	data = NULL;
-	setold();
-	fprintf (stderr," Load Success\n");
+	{
+		Bind(maxdimension,detailtexture);
+		free(data);
+		data = NULL;
+		setold();
+	}
+	else
+		FileNotFound(texfilename);
 }
 
 Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXTURE_TARGET target, enum TEXTURE_IMAGE_TARGET imagetarget, GFXBOOL force_load, int maxdimension,GFXBOOL detailtexture)
 {
-
   data = NULL;
   ismipmapped  = mipmap;
   InitTexture();
@@ -334,6 +204,8 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
   this->stage = stage;
   texfilename = string(FileName);
   string tempstr;
+  if( checkbad( texfilename))
+  	return;
   if(checkold(texfilename,false,tempstr)) {
     return;
   } else {
@@ -343,7 +215,7 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
     }
   }
 
-  fprintf (stderr,"1.Loading bmp file %s ",FileName);
+  //VSFileSystem::vs_fprintf (stderr,"1.Loading bmp file %s ",FileName);
 	char *t= strdup (FileName);
 	int tmp = strlen(FileName);
 	if (tmp>3) {
@@ -351,53 +223,66 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
 	  t[tmp-2] = 'l';
 	  t[tmp-1] = 'p';
 	}
-	FILE *fp2=0;
-	if (t)
-	  if (t[0]!='\0')
-	    fp2 = fopen(t, "rb");
-
+	VSFile f2;
+	VSError err2=VSFileSystem::FileNotFound;
+	if (t){
+		if (t[0]!='\0'){
+		static bool use_alphamap              = parse_bool(vs_config->getVariable("graphics",
+                                                  "bitmap_alphamap",
+                                                  "true"));
+		if (use_alphamap)
+		    err2 = f2.OpenReadOnly(t, TextureFile);
+		}
+	}
 
 	
-	if(fp2) {
+	if(err2<=Ok) {
 	  //texfilename += string(t);
 	}
 	//	this->texfilename = texfilename;
 	//strcpy (filename,texfilename.c_str());
-	FILE *fp = NULL;
+	VSFile f;
+	VSError err;
 	if (FileName)
 	  if (FileName[0])
-	    fp = fopen (FileName, "rb");
-	bool shared = (fp==NULL);
-	modold (texfilename,shared,texfilename);
+	    err = f.OpenReadOnly (FileName, TextureFile);
+	bool shared = (err==Shared);
+	//modold (texfilename,shared,texfilename);
+	/*
 	if (shared) {
 	  if (FileName)
 	    if (FileName[0]) {
-	      string tmp =GetSharedTexturePath (FileName);
-	      fp = fopen (tmp.c_str(),"rb");
+	      //string tmp =VSFileSystem::GetSharedTexturePath (FileName);
+	      err = f.OpenReadOnly (FileName,TextureFile);
 	    }
 	}
+	*/
 	free ( t);
-	if (fp&&g_game.use_textures==0&&!force_load) {
-	  fclose (fp);
-	  fp=NULL;
+	if (err<=Ok&&g_game.use_textures==0&&!force_load) {
+	  f.Close();
+	  err = Unspecified;
 	}
-	if (!fp)
+	if (err>Ok)
 	{
 		FileNotFound(texfilename);
-      	fprintf (stderr, "%s, not found",FileName);
-		if (fp2) {
-			fclose (fp2);
+      	VSFileSystem::vs_fprintf (stderr, "\n%s, not found\n",FileName);
+		if (err2<=Ok) {
+			f2.Close();
 		}
 		return;
 	}
+	modold (texfilename,shared,texfilename);
 	if (texfilename.find("white")==string::npos)
 		bootstrap_draw("Loading "+string(FileName));
 	
 	//	strcpy(filename, FileName);
-	int bpp;
-	int format;
 	this->texfilename=texfilename;
-	data = readImage (fp,bpp,format,sizeX,sizeY,palette,NULL/*texTransform*/,true);
+	if( err2>Ok)
+		data = this->ReadImage( &f, NULL, true, NULL);
+	else
+		data = this->ReadImage( &f, NULL, true, &f2);
+	/*
+	data = readImage (f,bpp,format,sizeX,sizeY,palette,NULL,true);
 	if (data) {
 	  //FIXME deal with palettes and grayscale with alpha
 	  if (!(format&PNG_HAS_COLOR)||(format&PNG_HAS_PALETTE)) {
@@ -422,22 +307,22 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
 	}else {
 	  char head1;
 	  char head2;
-	  fseek (fp,0,SEEK_SET);
-	  fread (&head1,1,1,fp);
-	  fread (&head2,1,1,fp);
+	  f.Begin();
+	  f.Read (&head1, 1);
+	  f.Read(&head2,1);
 	  if (toupper(head1)!='B'||toupper (head2)!='M') {
 		FileNotFound(texfilename);
-		fclose (fp);
-		if (fp2) {
-			fclose(fp2);
+		f.Close();
+		if (err2<=Ok) {
+			f2.Close();
 		}
 		return;
 	  }
 	  //seek back to beginning
-	  fseek (fp,SIZEOF_BITMAPFILEHEADER,SEEK_SET);
+	  f.GoTo(SIZEOF_BITMAPFILEHEADER);
 	  //long temp;
 	  BITMAPINFOHEADER info;
-	  fread(&info, SIZEOF_BITMAPINFOHEADER,1,fp);
+	  f.Read(&info, SIZEOF_BITMAPINFOHEADER);
 	  sizeX = le32_to_cpu(info.biWidth);	
 	  sizeY = le32_to_cpu(info.biHeight);
 	  
@@ -447,7 +332,7 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
 	  if(le16_to_cpu(info.biBitCount) == 24)
 	    {
 	      mode = _24BITRGBA;
-	      if(fp2)
+	      if(err2<=Ok)
 		mode = _24BITRGBA;
 	      data = NULL;
 	      data= (unsigned char *)malloc (sizeof(unsigned char)*4*sizeY*sizeX); // all bitmap data needs to be 32 bits
@@ -458,13 +343,13 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
 		  int itimes4width= 4*i*sizeX;//speed speed speed (well if I really wanted speed Pos'd have wrote this function)
 		  for (unsigned int j=0; j<sizeX;j++)
 		    {
-		      if(fp2)
-					fread(data+3, sizeof(unsigned char), 1, fp2);
+		      if(err2<=Ok)
+					f2.Read(data+3, sizeof(unsigned char));
 		      else
 			*(data+3) = 0xff; // default alpha = 1
 		      for (int k=2; k>=0;k--)
 			{
-					fread (data+k+4*j+itimes4width,sizeof (unsigned char),1,fp);
+					f.Read (data+k+4*j+itimes4width,sizeof (unsigned char));
 			}
 		      
 		    }
@@ -481,7 +366,7 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
 	      unsigned char ctemp;
 		for(int palcount = 0; palcount < 256; palcount++)
 		  {
-		    fread(paltemp, SIZEOF_RGBQUAD, 1, fp);
+		    f.Read(paltemp, SIZEOF_RGBQUAD);
 		    ctemp = paltemp[0];
 		    paltemp[0] = paltemp[2];
 		    paltemp[2] = ctemp;
@@ -493,21 +378,29 @@ Texture::Texture(const char * FileName, int stage, enum FILTER mipmap, enum TEXT
 		  {
 		    for (unsigned int j=0; j<sizeX;j++)
 		      {
-			fread (data+ j + i * sizeX,sizeof (unsigned char),1,fp);
+				f.Read(data+ j + i * sizeX,sizeof (unsigned char));
 		      }
 		  }
 	    }
 	}
-	fprintf (stderr,"Bind... ");
-	Bind(maxdimension,detailtexture);
- 	fclose (fp);
-	if (fp2)
-	  fclose (fp2);
+	//VSFileSystem::vs_fprintf (stderr,"Bind... ");
+ 	f.Close();
+	if (err2<=Ok)
+	  f2.Close();
+	*/
 	if (data)
-	  free(data);
-	data = NULL;
-	setold();
-	fprintf (stderr," Load Success\n");
+	{
+		Bind(maxdimension,detailtexture);
+		free(data);
+		data = NULL;
+		setold();
+	}
+	else
+		FileNotFound(texfilename);
+	f.Close();
+	if( f2.Valid())
+		f2.Close();
+	//VSFileSystem::vs_fprintf (stderr," Load Success\n");
 }
 
 Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, enum FILTER  mipmap, enum TEXTURE_TARGET target, enum TEXTURE_IMAGE_TARGET imagetarget, float alpha, int zeroval, GFXBOOL force_load, int maxdimension,GFXBOOL detailtexture)
@@ -530,31 +423,53 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 	    return;
 	  }
 	}
-	fprintf (stderr,"2.Loading bmp file %s alp %s ",FileNameRGB,FileNameA);
+	//VSFileSystem::vs_fprintf (stderr,"2.Loading bmp file %s alp %s ",FileNameRGB,FileNameA);
 	//this->texfilename = texfilename;
 	//strcpy (filename,texfilename.c_str());
-	FILE *fp = NULL;
-	fp = fopen (FileNameRGB, "rb");
-	bool shared = (fp==NULL);
+	VSFile f;
+	VSError err = Unspecified;
+	err = f.OpenReadOnly(FileNameRGB, TextureFile);
+	bool shared = (err==Shared);
 	modold (texfilename,shared,texfilename);
-	if (shared) {
-	  string tmp = GetSharedTexturePath (FileNameRGB);
-	  fp = fopen (tmp.c_str(),"rb");
+	if (err<=Ok&&g_game.use_textures==0&&!force_load) {
+	  f.Close();
+	  err = Unspecified;
 	}
-	if (fp&&g_game.use_textures==0&&(!force_load)) {
-	  fclose (fp);
-	  fp=NULL;
-	}
-	if (!fp)
+	if (err>Ok)
 	{
 	  FileNotFound(texfilename);
 	  return;
 	}
-	int bpp;
-	int format;
-	FILE * fp1=NULL;
+	VSFile f1;
+	VSError err1=Unspecified;
+	bool shared1;
+	if (FileNameA)
+	{
+           static bool use_alphamap 
+              = parse_bool(vs_config->getVariable("graphics",
+                                                  "bitmap_alphamap",
+                                                  "true"));
+           if (use_alphamap) {
+              std::string tmp;
+              f1.OpenReadOnly( FileNameA, TextureFile);
+              
+              shared1 = (err1==Shared);
+              if (err1>Ok)
+                 {
+                    data = NULL;
+                    FileNameA = NULL;
+                    //VSFileSystem::vs_close(fp);
+                    //*this = Texture(FileNameRGB, NULL);
+                    //return;
+                 }
+           }else FileNameA=0;
+	}
 	this->texfilename=texfilename;
-	data = readImage (fp,bpp,format,sizeX,sizeY,palette,NULL/*texTransform*/,true);
+	if( err1>Ok)
+		data = this->ReadImage( &f, NULL, true, NULL);
+	else
+		data = this->ReadImage( &f, NULL, true, &f1);
+	/*
 	if (data) {
 	  //FIXME deal with palettes and grayscale with alpha
 	  if (!(format&PNG_HAS_COLOR)||(format&PNG_HAS_PALETTE)) {
@@ -580,66 +495,58 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 	}else {
 	  char head1;
 	  char head2;
-	  fseek (fp,0,SEEK_SET);
-	  fread (&head1,1,1,fp);
-	  fread (&head2,1,1,fp);
+	  f.Begin();
+	  f.Read(&head1,1);
+	  f.Read(&head2,1);
 	  if (toupper(head1)!='B'||toupper (head2)!='M') {
 		FileNotFound(texfilename);
-		fclose (fp);
-		if (fp1) {
-			fclose(fp1);
+		f.Close();
+		if (err1<=Ok) {
+			f1.Close();
 		}
 		return;
 	  }
 	  ///seek back to the beginning
-	  fseek (fp,SIZEOF_BITMAPFILEHEADER,SEEK_SET);
+	  f.GoTo(SIZEOF_BITMAPFILEHEADER);
 	  //long temp;
 	  BITMAPINFOHEADER info;
-	  fread(&info, SIZEOF_BITMAPINFOHEADER,1,fp);
+	  f.Read(&info, SIZEOF_BITMAPINFOHEADER);
 	  sizeX = le32_to_cpu(info.biWidth);
 	  sizeY = le32_to_cpu(info.biHeight);
 	  BITMAPINFOHEADER info1;
 	  
-
-
-	  
 	  if (FileNameA)
-	    {
-	      
-	      std::string tmp;
-	      if (shared)
-		tmp = GetSharedTexturePath(FileNameA);
-	      else
-		tmp = FileNameA;
+	  {
+	    std::string tmp;
+		f1.OpenReadOnly( FileNameA, TextureFile);
 	     
-	      fp1 = fopen (tmp.c_str(), "rb");
-	      
-	      if (!fp1)
+		shared = (err1==Shared);
+	    if (err1>Ok)
 		{
 		  data = NULL;
 		  FileNameA = NULL;
-		  //fclose(fp);
-		  //*this = Texture(FileNameRGB, NULL);
+		  //VSFileSystem::vs_close(fp);
+		  // *this = Texture(FileNameRGB, NULL);
 		  //return;
 		}
-	      else
+	    else
 		{
-		  fseek (fp1,SIZEOF_BITMAPFILEHEADER,SEEK_SET);
+		  f1.GoTo(SIZEOF_BITMAPFILEHEADER);
 		  
-		  fread (&info1,SIZEOF_BITMAPINFOHEADER,1,fp1);
+		  f1.Read(&info1,SIZEOF_BITMAPINFOHEADER);
 		  if (sizeX != (unsigned int) le32_to_cpu(info1.biWidth)||sizeY!=(unsigned int)le32_to_cpu(info1.biHeight))
 		    {
 		      data = NULL;
-		      fclose (fp1);
-		      if (fp) 
-			fclose (fp);
+		      f1.Close();
+		      if (err<=Ok) 
+				f.Close();
 		      return;
 		    }
 		  RGBQUAD ptemp1;	
 		  if (le16_to_cpu(info1.biBitCount) == 8)
 		    {
 		      for (int i=0; i<256; i++)
-			fread(&ptemp1, sizeof(RGBQUAD), 1, fp1); //get rid of the palette for a b&w greyscale alphamap
+				f1.Read(&ptemp1, sizeof(RGBQUAD)); //get rid of the palette for a b&w greyscale alphamap
 		      
 		    }
 		}
@@ -653,15 +560,15 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 		for (unsigned int j=0; j<sizeX;j++)
 		  {
 		    for (int k=2; k>=0;k--) {
-		      fread (data+k+4*j+itimes4width,sizeof (unsigned char),1,fp);
+		      f.Read(data+k+4*j+itimes4width,sizeof (unsigned char));
 		    }
 		    if (FileNameA){
 		      if (le16_to_cpu(info1.biBitCount)==24)
 		      for (int k=2; k>=0;k--) {
-			fread (data+3+4*j+itimes4width,sizeof (unsigned char),1,fp1);
-			//*(data+3+4*j+itimes4width) = 30;
+				f1.Read(data+3+4*j+itimes4width,sizeof (unsigned char));
+			// *(data+3+4*j+itimes4width) = 30;
 		      } else {
-			fread (data+3+4*j+itimes4width,sizeof (unsigned char),1,fp1);
+				f1.Read(data+3+4*j+itimes4width,sizeof (unsigned char));
 		      }
 		    }
 		    else {
@@ -670,7 +577,7 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 		      else
 			data[4*j+itimes4width+3] = 255;
 		    }
-		    //*(data+3+4*j+itimes4width) = 30;
+		    // *(data+3+4*j+itimes4width) = 30;
 		    
 		    
 		  }
@@ -685,24 +592,24 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 	    unsigned char *paltemp = palette;
 	    unsigned char ctemp;
 	    for(int palcount = 0; palcount < 256; palcount++) {
-	      fread(paltemp, sizeof(RGBQUAD), 1, fp);
+	      f.Read(paltemp, sizeof(RGBQUAD));
 	      ctemp = paltemp[0];
 	      paltemp[0] = paltemp[2];
 	      paltemp[2] = ctemp;
 	      paltemp+=4;
 	    }
 	    if (!data) {
-	      if (fp)
-		fclose (fp);
-	      if (fp1)
-		fclose (fp1);
+	      if (err<=Ok)
+			f.Close();
+	      if (err1<=Ok)
+			f1.Close();
 	      return;
 	    }
 		//FIXME VEGASTRIKE???		int k=0;
 	    for (int i=sizeY-1; i>=0;i--) {
 	      for (unsigned int j=0; j<sizeX;j++)
 		{
-		  fread (&index,sizeof (unsigned char),1,fp);
+		  f.Read(&index,sizeof (unsigned char));
 		  data [4*(i*sizeX+j)] = palette[((short)index)*4];	
 		  data [4*(i*sizeX+j)+1] = palette[((short)index)*4+1];
 		  data [4*(i*sizeX+j)+2] = palette[((short)index)*4+2];
@@ -718,10 +625,10 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 		    for (unsigned int j=0; j<sizeX;j++) {
 		      if (le16_to_cpu(info1.biBitCount)==24)
 			for (int k=2; k>=0;k--) {
-			  fread (data+3+4*j+itimes4width,sizeof (unsigned char),1,fp1);
+			  f1.Read(data+3+4*j+itimes4width,sizeof (unsigned char));
 			}
 		      else {
-			fread (data+3+4*j+itimes4width,sizeof (unsigned char),1,fp1);
+				f1.Read(data+3+4*j+itimes4width,sizeof (unsigned char));
 		      }
 		    }
 		  }
@@ -759,18 +666,22 @@ Texture::Texture (const char * FileNameRGB, const char *FileNameA, int stage, en
 	    
 	  }
 	}
-	fprintf (stderr,"Bind... ");
-	Bind(maxdimension,detailtexture);
-	if (fp)
-	  fclose(fp);
-	if (fp1) {
-	  fclose (fp1);
-	}
+	//VSFileSystem::vs_fprintf (stderr,"Bind... ");
+	*/
 	if (data)
+	{
+	  Bind(maxdimension,detailtexture);
 	  free(data);
-	data = NULL;
-	setold();
-	fprintf (stderr,"Load Success\n");
+	  data = NULL;
+	  setold();
+	}
+	else
+		FileNotFound( texfilename);
+	f.Close();
+	if (err1<=Ok) {
+	  f1.Close();
+	}
+	//VSFileSystem::vs_fprintf (stderr,"Load Success\n");
 }
 Texture::~Texture()
 	{
