@@ -22,10 +22,10 @@
 #define BACKGROUND_H
 #include "star.h"
 class SphereMesh;
-struct Texture;
+class Texture;
 class Background {
   bool Enabled;
-  StarVlist stars;
+  StarVlist *stars;
   Texture *up;
   Texture *left;
   Texture *front;
