@@ -1,10 +1,10 @@
 #include "gauge.h"
 
 
-Gauge::Gauge (const char *file, DIRECTION up): Sprite(file) {
+Gauge::Gauge (const char *file, DIRECTION up): VSSprite(file) {
   dir = up;
   float sx,sy;
-  Sprite::GetSize(sx,sy);
+  VSSprite::GetSize(sx,sy);
   SetSize (-sx,-sy);
 }
 void Gauge::SetSize (float x, float y) {
@@ -13,11 +13,11 @@ void Gauge::SetSize (float x, float y) {
   } else if (dir==GAUGE_LEFT) {
     x = -x;
   }
-  Sprite::SetSize (x,y);
+  VSSprite::SetSize (x,y);
 
 }
 void Gauge::GetSize (float &x, float &y) {
-  Sprite::GetSize (x,y);
+  VSSprite::GetSize (x,y);
   if (dir==GAUGE_UP) {
     y= -y;
   } else if (dir==GAUGE_LEFT) {
@@ -28,23 +28,23 @@ void Gauge::GetSize (float &x, float &y) {
 
 void Gauge::Draw (float percentage) {
   float sx,sy,px,py;
-  Sprite::GetSize (sx,sy);
-  Sprite::GetPosition(px,py);
+  VSSprite::GetSize (sx,sy);
+  VSSprite::GetPosition(px,py);
   switch (dir) {
   case GAUGE_RIGHT:
   case GAUGE_LEFT:
     SetST ((1-percentage),0);
-    Sprite::SetSize (sx*percentage,sy);
-    Sprite::SetPosition (px+sx*(1-percentage)*.5,py);
+    VSSprite::SetSize (sx*percentage,sy);
+    VSSprite::SetPosition (px+sx*(1-percentage)*.5,py);
     break;
   case GAUGE_DOWN:
   case GAUGE_UP:
     SetST (0,(1-percentage));
-    Sprite::SetSize (sx,sy*percentage);
-    Sprite::SetPosition (px,py+sy*(1-percentage)*.5);
+    VSSprite::SetSize (sx,sy*percentage);
+    VSSprite::SetPosition (px,py+sy*(1-percentage)*.5);
     break;
   }
-  Sprite::Draw();
-  Sprite::SetSize (sx,sy);
-  Sprite::SetPosition (px,py);
+  VSSprite::Draw();
+  VSSprite::SetSize (sx,sy);
+  VSSprite::SetPosition (px,py);
 }
