@@ -364,7 +364,8 @@ vector<Mesh*> Mesh::LoadMeshes(VSFileSystem::VSFile & Inputfile, const Vector &
 		  fprintf(Outputfile,"</Material>\n");
                   mesh->setEnvMap(reflect);
                   mesh->forceCullFace(cullface);
-                  mesh->setLighting(lighting);
+                  static bool forcelight=XMLSupport::parse_bool (vs_config->getVariable ("graphics","ForceLighting","true"));
+                  mesh->setLighting (forcelight||lighting); 
                   xml.usenormals=usenormals;
                   xml.material.ar=ar;xml.material.ag=ag;xml.material.ab=ab;xml.material.aa=aa;
                   xml.material.dr=dr;xml.material.dg=dg;xml.material.db=db;xml.material.da=da;
@@ -392,8 +393,9 @@ vector<Mesh*> Mesh::LoadMeshes(VSFileSystem::VSFile & Inputfile, const Vector &
 	        int32bit numrefs=VSSwapHostIntToLittle(inmemfile[word32index+4].i32val);//number of reference points
 			fprintf(Outputfile,"<Logo type=\"%d\" rotate=\"%f\" size=\"%f\" offset=\"%f\">\n",type,rotation,size,offset);
                         struct MeshXML::ZeLogo l;
+                        l.type=type;l.rotate=rotation;l.size=size;l.offset=offset;
                         xml.logos.push_back(l);
-                        xml.logos.back().type=type;
+                        xml.logos.back().type=type;//and again!
                         xml.logos.back().rotate=rotation;
                         xml.logos.back().size=size;
                         xml.logos.back().offset=offset;
