@@ -6,15 +6,15 @@
 #include "drawlist.h"
 #include "navitemtypes.h"
 #include "gfx/masks.h"
-
-
+#include "navcomputer.h"
+#include "navpath.h"
 
 #define NAVTOTALMESHCOUNT 8	//	same as the button count, 1 mesh for screen and 1 per button(1+7)
 #define MAXZOOM 10
 
 
 void visitSystem (class Cockpit * cp, std::string systemname) ;
-
+void Beautify (string systemfile, string & sector, string & system);
 class NavigationSystem
 {
 public:
@@ -44,7 +44,10 @@ public:
 			string name;
 			QVector position;
 			std::vector<unsigned> lowerdestinations;
-			const float * col;
+			GFXColor col;
+		        bool part_of_path;
+		        std::set<NavPath *> paths;
+			void UpdateColor();
 			string &GetName();
 			const string &GetName() const;
 			bool isDrawable() const;
@@ -52,13 +55,15 @@ public:
 			const QVector &Position () const;
 			unsigned GetDestinationIndex (unsigned index) const;
 			unsigned GetDestinationSize() const;
-			GFXColor GetColor() const;
-			SystemInfo(const string &name, const QVector &position, const std::vector<std::string> &destinations, const CachedSystemIterator *csi);
+			GFXColor GetColor();
+			SystemInfo(const string &name);
+		        SystemInfo(const string &name, const QVector &position, const std::vector<std::string> &destinations, CachedSystemIterator *csi);
+		        void loadData(map<string, unsigned> * index_table);
 		};
 
 	private:
-          friend class SystemInfo;//inner class needs to be friend in gcc-295
-		vector<SystemInfo> systems;
+                friend class SystemInfo;//inner class needs to be friend in gcc-295
+ 		vector<SystemInfo> systems;
 		unsigned currentPosition;
 		CachedSystemIterator(const CachedSystemIterator &other); // May be really slow. Don't try this at home.
 		CachedSystemIterator operator ++ (int); // Also really slow because it has to use the copy constructor.
@@ -81,13 +86,68 @@ public:
 		CachedSystemIterator & operator ++ ();
 	};
 
+	class CachedSectorIterator {
+
+	public:
+		class SectorInfo {
+		public:
+			string name;
+			std::vector<unsigned> subsystems;
+			string &GetName();
+			const string &GetName() const;
+			unsigned GetSubsystemIndex (unsigned index) const;
+			unsigned GetSubsystemSize() const;
+			SectorInfo(const string &name);
+		        void AddSystem(unsigned index);
+		};
+
+	private:
+          friend class SectorInfo;//inner class needs to be friend in gcc-295
+		vector<SectorInfo> sectors;
+		unsigned currentPosition;
+		CachedSectorIterator(const CachedSectorIterator &other); // May be really slow. Don't try this at home.
+		CachedSectorIterator operator ++ (int); // Also really slow because it has to use the copy constructor.
+
+	public:
+		CachedSectorIterator();
+		CachedSectorIterator (CachedSystemIterator &systemIter);
+		void init(CachedSystemIterator &systemIter);
+		bool seek(unsigned position=0);
+		unsigned getIndex() const;
+		unsigned size() const;
+		bool done () const;
+		SectorInfo & operator[] (unsigned pos);
+		const SectorInfo & operator[] (unsigned pos) const;
+		SectorInfo &operator* ();
+		const SectorInfo &operator* () const;
+		SectorInfo *operator-> ();
+		const SectorInfo *operator-> () const;
+		CachedSectorIterator & next ();
+		CachedSectorIterator & operator ++ ();
+	};
 
 
 
 private:
-std::string currentsystem;//FIXME
-std::string systemselection;
+friend class NavComputer;
+friend class CurrentPathNode;
+friend class TargetPathNode;
+friend class AbsolutePathNode;
+friend class CriteriaContains;
+friend class CriteriaOwnedBy;
+friend class CriteriaSector;
+friend class NavPath;
+friend void visitSystemHelp (Cockpit * cp, string systemname,float num);
+NavComputer * navcomp;
+PathManager * pathman;
+unsigned currentsystemindex;
+unsigned focusedsystemindex;
+unsigned destinationsystemindex;
+unsigned systemselectionindex;
+unsigned sectorselectionindex;
 CachedSystemIterator systemIter;
+CachedSectorIterator sectorIter;
+std::vector<unsigned> path;
 class navscreenoccupied* screenoccupation;
 class Mesh * mesh[NAVTOTALMESHCOUNT];
 int reverse;
@@ -116,6 +176,9 @@ enum ViewType {VIEW_2D, VIEW_ORTHO, VIEW_3D, VIEW_MAX};
 int system_view;
 int galaxy_view;
 
+int path_view;
+enum PathType {PATH_OFF, PATH_ON, PATH_ONLY, PATH_MAXIMUM};
+
 bool system_multi_dimensional;
 bool galaxy_multi_dimensional;
 
@@ -134,14 +197,21 @@ bool mouse_wentup[5];
 bool mouse_wentdown[5];
 UnitContainer currentselection;
 GFXColor* factioncolours;
+GFXColor currentcol;
+GFXColor destinationcol;
+GFXColor selectcol;
+GFXColor pathcol;
 
 
-
+//DrawSectorList's scroll control variables
+unsigned sectorOffset;
+unsigned systemOffset;
 
 int whattodraw;
 //	bit 0 = undefined
 //	bit	1 = draw system screen / mission screen
-//	bit 2 = draw galaxy screen
+//	bit 2 = draw galaxy/system ship/mission screen
+//	bit 3 = draw sector list screen in mission mode
 
 
 							//	coordinates done 'over left->right' by 'up bottom->top'
@@ -185,7 +255,15 @@ void TranslateCoordinates(QVector &pos, QVector &pos_flat, float center_nav_x, f
 void TranslateAndDisplay (QVector &pos, QVector &pos_flat, float center_nav_x, float center_nav_y, float themaxvalue,
 	float &zscale, float &zdistance, float &the_x, float &the_y, float &system_item_scale_temp, bool system_not_galaxy);
 
+void DisplayOrientationLines (float the_x, float the_y, float the_x_flat, float the_y_flat, bool system_not_galaxy);
+
 bool CheckForSelectionQuery();
+void setCurrentSystemIndex(unsigned newSystemIndex);
+void setFocusedSystemIndex(unsigned newSystemIndex);
+void setDestinationSystemIndex(unsigned newSystemIndex);
+
+bool BFS(unsigned originIndex, unsigned destIndex);
+bool DoubleRootedBFS(unsigned originIndex, unsigned destIndex);
 //*************************
 
 
@@ -195,8 +273,8 @@ bool CheckForSelectionQuery();
 
 
 public:
-NavigationSystem() {draw = -1; whattodraw=(1|2);}
- ~NavigationSystem();
+NavigationSystem();
+~NavigationSystem();
 static void DrawCircle(float x, float y, float size, const GFXColor &col );
 static void DrawHalfCircleTop(float x, float y, float size, const GFXColor &col );
 static void DrawHalfCircleBottom(float x, float y, float size, const GFXColor &col );
@@ -207,6 +285,7 @@ static void DrawMissile(float x, float y, float size, const GFXColor &col );
 static void DrawTargetCorners(float x, float y, float size, const GFXColor &col );
 static void DrawNavCircle(float x, float y, float rot_x, float rot_y, float size, const GFXColor &col );
 void setCurrentSystem(string newSystem);
+std::string getCurrentSystem();
 
 void DrawButton(float &x1, float &x2, float &y1, float &y2, int button_number, bool outline);
 void DrawButtonOutline(float &x1, float &x2, float &y1, float &y2, const GFXColor &col);
@@ -222,6 +301,7 @@ void DrawSystem();
 void DrawGalaxy();
 void DrawMission();
 void DrawShip();
+void DrawSectorList();
 void SetMouseFlipStatus();
 void ScreenToCoord(float &x);
 void IntersectBorder(float & x, float & y, const float & x1, const float & y1) const;
@@ -229,6 +309,7 @@ void Draw();
 void Setup();
 void SetDraw(bool n);
 void ClearPriorities();
+void updatePath();
 
 static int mousex;
 static int mousey;
