@@ -1,6 +1,8 @@
-#include <config.h>
-
 #include "vsnet_thread.h"
+#include "vsnet_debug.h"
+
+using namespace std;
+
 #ifdef USE_NO_THREAD
 
 /*------------------------------------------------------------*
