@@ -117,7 +117,7 @@
   WRAPPED0(int,DockedOrDocking,0)
   WRAPPED0(int,GetNumMounts,0)
   EXPORT_UTIL0(UnitWrapper,owner)
-  voidEXPORT_UTIL1(performDockingOperations,UnitWrapper,unitToDockWith)
+  voidEXPORT_UTIL2(performDockingOperations,UnitWrapper,unitToDockWith,int,acootuallydock)
 
 	EXPORT_UTIL0(string,getFactionName)
 	EXPORT_UTIL0(int,getFactionIndex)
@@ -133,8 +133,10 @@
 	EXPORT_UTIL1(bool,setFgDirective,string,inp)
 //	EXPORT_UTIL0(int,getFgSubnumber)
 	EXPORT_UTIL3(int,removeCargo,string,s, int,quantity, bool, erasezero)
+	EXPORT_UTIL3(int,removeWeapon,string,name, int,offset, bool, loop)
 	EXPORT_UTIL5(float,upgrade,string,file,int,mountoffset,int, subunitoffset, bool, force,bool, loop_through_mounts)
 	EXPORT_UTIL1(int, addCargo, Cargo, carg)
+	EXPORT_UTIL1(int, forceAddCargo, Cargo, carg)
 	EXPORT_UTIL2(bool, incrementCargo,float, percentagechange,int, quantity)
 	EXPORT_UTIL1(bool,decrementCargo,float, percentagechange)
 	EXPORT_UTIL1(float, getDistance,UnitWrapper, un)
