@@ -16,7 +16,7 @@
 extern Unit ** fighters;
 extern Hashtable<std::string, StarSystem, 127> star_system_table;
 void CacheJumpStar (bool destroy) {
-  static Animation * cachedani=new Animation (vs_config->getVariable ("graphics","jumpgate","explosion_orange.ani").c_str(),true,.1,MIPMAP,false);
+  static Animation * cachedani=new Animation (vs_config->getVariable ("graphics","jumpgate","warp.ani").c_str(),true,.1,MIPMAP,false);
   if (destroy)
     delete cachedani;
 }
@@ -70,7 +70,6 @@ void GameStarSystem::VolitalizeJumpAnimation (const int ani) {
     AnimationNulls.push_back (ani);
   }
 }
-extern void SetShieldZero(Unit*);
 
 void GameStarSystem::DrawJumpStars() {
   for (unsigned int kk=0;kk<pendingjump.size();kk++) { 
@@ -80,7 +79,7 @@ void GameStarSystem::DrawJumpStars() {
       if (un) {
 	Vector p,q,r;
 	un->GetOrientation (p,q,r);
-        SetShieldZero(un);
+
 	JumpAnimations[k].a->SetPosition (un->Position()+r.Cast()*un->rSize()*(pendingjump[kk]->delay+.25));
 	JumpAnimations[k].a->SetOrientation (p,q,r);
 	static float JumpStarSize = XMLSupport::parse_float (vs_config->getVariable ("graphics","jumpgatesize","1.75"));
