@@ -48,6 +48,11 @@ public:
 	PythonUnitIter getUnitList();
 ///This function gets a unit given a number (how many iterations to go down in the iterator)
 	Unit *getUnit(int index);
+	Unit *getScratchUnit();
+	void setScratchUnit(Unit *);
+	void precacheUnit(std::string name, std::string faction);
+        QVector getScratchVector();
+        void setScratchVector(QVector);
 	int getNumUnits();
 	void cacheAnimation (string anim);
 ///this function launches a wormhole or ajump point.
@@ -61,6 +66,7 @@ public:
 			QVector pos, 
 			string squadlogo, 
 			string destinations);
+	std::string vsConfig(std::string category,std::string option,std::string def);
 ///this function launches a normal fighter  the name is the flightgroup name, the type is the ship type, the faction is who it belongs to, the unittype is usually "unit" unless you want to make asteroids or nebulae or jump points or planets.  the aistring is either a python filename or "default"  the nr of ships is the number of ships to be launched with this group, the number of waves is num reinforcements... the position is a tuple (x,y,z) where they appear and the squadlogo is a squadron image...you can leave this the empty string '' for the default squadron logo. 
 	Unit* launch (string name_string,string type_string,string faction_string,string unittype, string ai_string,int nr_of_ships,int nr_of_waves, QVector pos, string sqadlogo);
 ///this gets a random cargo type (useful for cargo missions) from either any category if category is '' or else from a specific category  'Contraband'  comes to mind!
@@ -180,6 +186,7 @@ public:
 	Unit *getPlayer();
 ///this gets a player number (if in splitscreen mode)
 	Unit *getPlayerX(int which);
+	void StopAllSounds(void);
 	unsigned int getCurrentPlayer();
 ///this gets the number of active players
 	int getNumPlayers ();
